==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_mas.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_mas extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "KES", "Ksh" },
            { "aed", "Iropiyian\u00ed \u0254\u0301\u0254\u0304 lmarabu" },
            { "aoa", "Iropiyian\u00ed e Angola" },
            { "aud", "Iropiyian\u00ed e Austria" },
            { "bhd", "Iropiyian\u00ed e Bahareini" },
            { "bif", "Iropiyian\u00ed e Burundi" },
            { "bwp", "Iropiyian\u00ed e Botswana" },
            { "cad", "Iropiyian\u00ed e Kanada" },
            { "cdf", "Iropiyian\u00ed e Kongo" },
            { "chf", "Iropiyian\u00ed e Uswisi" },
            { "cny", "Iropiyian\u00ed e China" },
            { "cve", "Iropiyian\u00ed e Kepuvede" },
            { "djf", "Iropiyian\u00ed e Jibuti" },
            { "dzd", "Iropiyian\u00ed e Algeria" },
            { "egp", "Iropiyian\u00ed e Misri" },
            { "ern", "Iropiyian\u00ed e Eritrea" },
            { "etb", "Iropiyian\u00ed e Uhabeshi" },
            { "eur", "Iropiyian\u00ed e yuro" },
            { "gbp", "Iropiyian\u00ed e Nk\u0268\u0301resa" },
            { "ghc", "Iropiyian\u00ed e Ghana" },
            { "gmd", "Iropiyian\u00ed e Gambia" },
            { "gns", "Iropiyian\u00ed e Gine" },
            { "inr", "Iropiyian\u00ed e India" },
            { "jpy", "Iropiyian\u00ed e Japani" },
            { "kes", "Iropiyian\u00ed e Kenya" },
            { "kmf", "Iropiyian\u00ed e Komoro" },
            { "lrd", "Iropiyian\u00ed e Liberia" },
            { "lsl", "Iropiyian\u00ed e Lesoto" },
            { "lyd", "Iropiyian\u00ed e Libya" },
            { "mad", "Iropiyian\u00ed e Moroko" },
            { "mga", "Iropiyian\u00ed e Bukini" },
            { "mro", "Iropiyian\u00ed e Moritania (1973\u20132017)" },
            { "mru", "Iropiyian\u00ed e Moritania" },
            { "mur", "Iropiyian\u00ed e Morisi" },
            { "mwk", "Iropiyian\u00ed e Malawi" },
            { "mzm", "Iropiyian\u00ed e Msumbiji" },
            { "nad", "Iropiyian\u00ed e Namibia" },
            { "ngn", "Iropiyian\u00ed e Nijeria" },
            { "rwf", "Iropiyian\u00ed e Rwanda" },
            { "sar", "Iropiyian\u00ed e Saudi" },
            { "scr", "Iropiyian\u00ed e Shelisheli" },
            { "sdg", "Iropiyian\u00ed e Sudani" },
            { "shp", "Iropiyian\u00ed e Santahelena" },
            { "sll", "Iropiyian\u00ed e leoni" },
            { "sos", "Iropiyian\u00ed e Somalia" },
            { "std", "Iropiyian\u00ed e Saotome (1977\u20132017)" },
            { "stn", "Iropiyian\u00ed e Saotome" },
            { "szl", "Iropiyian\u00ed e lilangeni" },
            { "tnd", "Iropiyian\u00ed e Tunisia" },
            { "tzs", "Iropiyian\u00ed e Tanzania" },
            { "ugx", "Iropiyian\u00ed e Uganda" },
            { "usd", "Iropiyian\u00ed \u0254\u0301\u0254\u0304 lamarekani" },
            { "xaf", "Iropiyian\u00ed e CFA BEAC" },
            { "xof", "Iropiyian\u00ed e CFA BCEAO" },
            { "zar", "Iropiyian\u00ed e Afrika Kusini" },
            { "zmk", "Iropiyian\u00ed e Sambia (1968\u20132012)" },
            { "zmw", "Iropiyian\u00ed e Sambia" },
            { "zwd", "Iropiyian\u00ed e Simbabwe" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_mas.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_mas extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "KES", "Ksh" },
            { "aed", "Iropiyian\u00ed \u0254\u0301\u0254\u0304 lmarabu" },
            { "aoa", "Iropiyian\u00ed e Angola" },
            { "aud", "Iropiyian\u00ed e Austria" },
            { "bhd", "Iropiyian\u00ed e Bahareini" },
            { "bif", "Iropiyian\u00ed e Burundi" },
            { "bwp", "Iropiyian\u00ed e Botswana" },
            { "cad", "Iropiyian\u00ed e Kanada" },
            { "cdf", "Iropiyian\u00ed e Kongo" },
            { "chf", "Iropiyian\u00ed e Uswisi" },
            { "cny", "Iropiyian\u00ed e China" },
            { "cve", "Iropiyian\u00ed e Kepuvede" },
            { "djf", "Iropiyian\u00ed e Jibuti" },
            { "dzd", "Iropiyian\u00ed e Algeria" },
            { "egp", "Iropiyian\u00ed e Misri" },
            { "ern", "Iropiyian\u00ed e Eritrea" },
            { "etb", "Iropiyian\u00ed e Uhabeshi" },
            { "eur", "Iropiyian\u00ed e yuro" },
            { "gbp", "Iropiyian\u00ed e Nk\u0268\u0301resa" },
            { "ghc", "Iropiyian\u00ed e Ghana" },
            { "gmd", "Iropiyian\u00ed e Gambia" },
            { "gns", "Iropiyian\u00ed e Gine" },
            { "inr", "Iropiyian\u00ed e India" },
            { "jpy", "Iropiyian\u00ed e Japani" },
            { "kes", "Iropiyian\u00ed e Kenya" },
            { "kmf", "Iropiyian\u00ed e Komoro" },
            { "lrd", "Iropiyian\u00ed e Liberia" },
            { "lsl", "Iropiyian\u00ed e Lesoto" },
            { "lyd", "Iropiyian\u00ed e Libya" },
            { "mad", "Iropiyian\u00ed e Moroko" },
            { "mga", "Iropiyian\u00ed e Bukini" },
            { "mro", "Iropiyian\u00ed e Moritania (1973\u20132017)" },
            { "mru", "Iropiyian\u00ed e Moritania" },
            { "mur", "Iropiyian\u00ed e Morisi" },
            { "mwk", "Iropiyian\u00ed e Malawi" },
            { "mzm", "Iropiyian\u00ed e Msumbiji" },
            { "nad", "Iropiyian\u00ed e Namibia" },
            { "ngn", "Iropiyian\u00ed e Nijeria" },
            { "rwf", "Iropiyian\u00ed e Rwanda" },
            { "sar", "Iropiyian\u00ed e Saudi" },
            { "scr", "Iropiyian\u00ed e Shelisheli" },
            { "sdg", "Iropiyian\u00ed e Sudani" },
            { "shp", "Iropiyian\u00ed e Santahelena" },
            { "sle", "Iropiyian\u00ed e leoni" },
            { "sll", "Iropiyian\u00ed e leoni (1964\u20142022)" },
            { "sos", "Iropiyian\u00ed e Somalia" },
            { "std", "Iropiyian\u00ed e Saotome (1977\u20132017)" },
            { "stn", "Iropiyian\u00ed e Saotome" },
            { "szl", "Iropiyian\u00ed e lilangeni" },
            { "tnd", "Iropiyian\u00ed e Tunisia" },
            { "tzs", "Iropiyian\u00ed e Tanzania" },
            { "ugx", "Iropiyian\u00ed e Uganda" },
            { "usd", "Iropiyian\u00ed \u0254\u0301\u0254\u0304 lamarekani" },
            { "xaf", "Iropiyian\u00ed e CFA BEAC" },
            { "xof", "Iropiyian\u00ed e CFA BCEAO" },
            { "zar", "Iropiyian\u00ed e Afrika Kusini" },
            { "zmk", "Iropiyian\u00ed e Sambia (1968\u20132012)" },
            { "zmw", "Iropiyian\u00ed e Sambia" },
            { "zwd", "Iropiyian\u00ed e Simbabwe" },
        };
        return data;
    }
}
